@@ -13,6 +13,7 @@ if [ ! -e /dev/.devfsd ] ; then
         mknod /dev/tiser2    c 115 10
 	mknod /dev/tiser3    c 115 11
         chmod 0660 /dev/tiser*
+	chgrp dialout /dev/tiser?
 else
         echo "Hmmm, looks like you have devfs mounted"
         ln -fs /dev/ticables/ser/0 /dev/tiser0
@@ -20,6 +21,7 @@ else
         ln -fs /dev/ticables/ser/2 /dev/tiser2
 	ln -fs /dev/ticables/ser/3 /dev/tiser3
 	chmod 0660 /dev/ticables/ser/?
+	chgrp dialout /dev/ticables/ser/?
 fi
 
         ln -fs /dev/tiser0 /dev/tiS0
